"""gsd-rfkill mock template

This creates the expected properties of the GNOME Settings Daemon's
rfkill object. You can specify any property such as AirplaneMode in
"parameters".
"""

# SPDX-License-Identifier: LGPL-3.0-or-later

__author__ = "Guido Günther"
__copyright__ = "2024 The Phosh Developers"

import dbus

from dbusmock import MOCK_IFACE

SYSTEM_BUS = False
BUS_NAME = "org.gnome.SettingsDaemon.Rfkill"
MAIN_OBJ = "/org/gnome/SettingsDaemon/Rfkill"
MAIN_IFACE = "org.gnome.SettingsDaemon.Rfkill"


def load(mock, parameters):
    props = dbus.Dictionary(
        {
            "AirplaneMode": parameters.get("AirplaneMode", False),
            "BluetoothAirplaneMode": parameters.get("BluetoothAirplaneMode", False),
            "BluetoothHardwareAirplaneMode": parameters.get("BluetoothHardwareAirplaneMode", False),
            "BluetoothHasAirplaneMode": parameters.get("BluetoothHasAirplanemode", True),
            "HardwareAirplaneMode": parameters.get("HardwareAirplaneMode", False),
            "HasAirplaneMode": parameters.get("HasAirplaneMode", True),
            "ShouldShowAirplaneMode": parameters.get("ShouldShowAirplaneMode", True),
            "WwanAirplaneMode": parameters.get("WwanAirplaneMode", False),
            "WwanHardwareAirplaneMode": parameters.get("WwanHardwareAirplaneMode", False),
            "WwanHasAirplaneMode": parameters.get("WwanHasAirplaneMode", True),
        },
        signature="sv",
    )
    mock.AddProperties(MAIN_IFACE, props)


@dbus.service.method(MOCK_IFACE, in_signature="b", out_signature="b")
def SetAirplaneMode(self, mode):
    """
    Convenience method to toggle airplane mode
    """
    self.props[MAIN_IFACE]["AirplaneMode"] = mode
    self.props[MAIN_IFACE]["BluetoothAirplaneMode"] = mode
    self.props[MAIN_IFACE]["WwanAirplaneMode"] = mode
    return mode



"""gnome-shell screensaver mock template

This creates the expected methods and properties of the
org.gnome.ScreenSaver object.
"""

# SPDX-License-Identifier: LGPL-3.0-or-later

__author__ = "Bastien Nocera"
__copyright__ = """
(c) 2013 Red Hat Inc.
(c) 2017 - 2022 Martin Pitt <martin@piware.de>
"""

BUS_NAME = "org.gnome.ScreenSaver"
MAIN_OBJ = "/org/gnome/ScreenSaver"
MAIN_IFACE = "org.gnome.ScreenSaver"
SYSTEM_BUS = False


def load(mock, _parameters):
    mock.AddMethods(
        MAIN_IFACE,
        [
            ("GetActive", "", "b", "ret = self.is_active"),
            ("GetActiveTime", "", "u", "ret = 1"),
            (
                "SetActive",
                "b",
                "",
                'self.is_active = args[0]; self.EmitSignal("", "ActiveChanged", "b", [self.is_active])',
            ),
            ("Lock", "", "", "time.sleep(1); self.SetActive(True)"),
            ("ShowMessage", "sss", "", ""),
            ("SimulateUserActivity", "", "", ""),
        ],
    )

    # default state
    mock.is_active = False



"""pytest fixtures for DBusMock"""

# SPDX-License-Identifier: LGPL-3.0-or-later

__author__ = "Martin Pitt"
__copyright__ = "(c) 2023 Martin Pitt <martin@piware.de>"

from typing import Iterator

import pytest

from dbusmock.testcase import BusType, PrivateDBus


@pytest.fixture(scope="session")
def dbusmock_system() -> Iterator[PrivateDBus]:
    """Export the whole DBusTestCase as a fixture, with the system bus started"""

    with PrivateDBus(BusType.SYSTEM) as bus:
        yield bus


@pytest.fixture(scope="session")
def dbusmock_session() -> Iterator[PrivateDBus]:
    """Export the whole DBusTestCase as a fixture, with the session bus started"""

    with PrivateDBus(BusType.SESSION) as bus:
        yield bus
